@@ -12,7 +12,7 @@
  */
 
 /*
-   Copyright (C) 1997-2025 by Erik Nolf
+   Copyright (C) 1997-2026 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -244,3 +244,7 @@ Int8 MDC_HACK_ACR=MDC_NO;               /* try to find acrnema tags         */
 /* XMedCon - GUI*/
 Int8 XMDC_GUI=MDC_NO;                   /* is program the GUI part?         */
 Int8 XMDC_WRITE_FRMT = MDC_FRMT_RAW;    /* default format to save           */
+
+Int8 XMDC_THEME_CHOICE = MDC_THEME_NONE;   /* which theme is choosen        */
+Int8 XMDC_THEME_ACTION = MDC_THEME_IGNORE; /* ignore,load,write,remove      */
+
