@@ -28,7 +28,7 @@
  */
 
 /*
-   Copyright (C) 1997-2025 by Erik Nolf
+   Copyright (C) 1997-2026 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -83,8 +83,7 @@ struct ExpMatDir {
 
 
 /*********************************************************/
-FILE *mdc_mat_open( fname, fmode)
-  char *fname, *fmode;
+FILE *mdc_mat_open(char *fname, char *fmode)
 {
   FILE *fptr;
 
@@ -93,16 +92,12 @@ FILE *mdc_mat_open( fname, fmode)
 
 }
 /*********************************************************/
-void mdc_mat_close( fptr)
-  FILE *fptr;
+void mdc_mat_close(FILE *fptr)
 {
   MdcCloseFile( fptr);
 }
 /*********************************************************/
-Int32 mdc_mat_rblk( fptr, blkno, bufr, nblks)
-  FILE *fptr;
-  Int32 blkno, nblks;
-  Uint8 *bufr;
+Int32 mdc_mat_rblk(FILE *fptr, Int32 blkno, Uint8 *bufr, Int32 nblks)
 {
   int r;
   fseeko( fptr, (off_t)(blkno-1)*MdcMatBLKSIZE, 0);
@@ -112,11 +107,7 @@ Int32 mdc_mat_rblk( fptr, blkno, bufr, nblks)
   return (0);
 }
 /*********************************************************/
-
-Int32 mdc_mat_list( fptr, mlist, lmax)
-  FILE *fptr;
-  struct Mdc_MatDir mlist[];
-  Int32 lmax;
+Int32 mdc_mat_list(FILE *fptr, struct Mdc_MatDir mlist[], Int32 lmax)
 {
   Int32 blk, num_entry, num_stored, i;
   Int32 nxtblk, matnum, strtblk, endblk, matstat;
@@ -159,10 +150,7 @@ Int32 mdc_mat_list( fptr, mlist, lmax)
   return (num_entry);
 }
 /*********************************************************/
-Int32 mdc_mat_list7( fptr, mlist, lmax)
-  FILE *fptr;
-  struct Mdc_MatDir mlist[];
-  Int32 lmax;
+Int32 mdc_mat_list7(FILE *fptr, struct Mdc_MatDir mlist[], Int32 lmax)
 {
   Int32 blk, num_entry, num_stored, i;
   Int32 nxtblk, matnum, strtblk, endblk, matstat;
@@ -206,9 +194,7 @@ Int32 mdc_mat_list7( fptr, mlist, lmax)
 }
 
 /*********************************************************/
-Int32 MdcSWAW( from, to, length)
-  Uint16 from[], to[];
-  Int32 length;
+Int32 MdcSWAW(Uint16 from[], Uint16 to[], Int32 length)
 {
   Uint16 temp;
   Int32 i;
@@ -222,9 +208,7 @@ Int32 MdcSWAW( from, to, length)
 }
 
 /*********************************************************/
-Int32 MdcSWAB( from, to, length)
-  Uint8 from[], to[];
-  Int32 length;
+Int32 MdcSWAB(Uint8 from[], Uint8 to[], Int32 length)
 {
   Uint16 temp;
   Int32 i;
@@ -263,8 +247,7 @@ Int32 MdcSWAB( from, to, length)
  */
 /********************************************************
   new version supporting 512 planes, 1024 planes, 8 data types */
-Int32 mdc_mat_numcod( frame, plane, gate, data, bed)
-  Int32 frame, plane, gate, data, bed;
+Int32 mdc_mat_numcod(Int32 frame, Int32 plane, Int32 gate, Int32 data, Int32 bed)
 {
   Int32 matnum8data16bed64gate1024plane512frame, loPlane, hiPlane = 0, loData, hiData = 0;
 
@@ -280,8 +263,7 @@ Int32 mdc_mat_numcod( frame, plane, gate, data, bed)
 }
 /********************************************************
   new version supporting 512 planes, 1024 planes, 8 data types */
-Int32 mdc_mat_numdoc( matnum, matval)
-  Int32 matnum; struct Mdc_Matval *matval;
+Int32 mdc_mat_numdoc(Int32 matnum, struct Mdc_Matval *matval)
 {
   Int32 loPlane, hiPlane = 0, loData, hiData = 0;
 
@@ -297,8 +279,7 @@ Int32 mdc_mat_numdoc( matnum, matval)
   return 0;
 }
 /*********************************************************/
-Int32 mdc_mat_lookup( fptr, matnum, entry)
-  FILE *fptr; Int32 matnum; struct Mdc_MatDir *entry;
+Int32 mdc_mat_lookup(FILE *fptr, Int32 matnum, struct Mdc_MatDir *entry)
 {
 
   Int32 blk, i;
@@ -338,8 +319,7 @@ Int32 mdc_mat_lookup( fptr, matnum, entry)
 }
 
 /*********************************************************/
-Int32 mdc_mat_lookup7( fptr, matnum, entry)
-  FILE *fptr; Int32 matnum; struct Mdc_MatDir *entry;
+Int32 mdc_mat_lookup7(FILE *fptr, Int32 matnum, struct Mdc_MatDir *entry)
 {
 
   Int32 blk, i;
@@ -379,8 +359,7 @@ Int32 mdc_mat_lookup7( fptr, matnum, entry)
 }
 
 /*********************************************************/
-Int32 mdc_mat_read_main_header( fptr, h)
-  FILE *fptr; Mdc_Main_header *h;
+Int32 mdc_mat_read_main_header(FILE *fptr, Mdc_Main_header *h)
 {
   Int16 b[256];
   char *bb;
@@ -451,8 +430,7 @@ Int32 mdc_mat_read_main_header( fptr, h)
   return (0);
 }
 /*********************************************************/
-Int32 mdc_mat_read_matrix_data( fptr, blk, nblks, bufr)
-  FILE *fptr; Int32 blk, nblks; Int16 bufr[];
+Int32 mdc_mat_read_matrix_data(FILE *fptr, Int32 blk, Int32 nblks, Int16 bufr[])
 {
   Int32 error ;
   Mdc_Main_header h ;
@@ -465,8 +443,7 @@ Int32 mdc_mat_read_matrix_data( fptr, blk, nblks, bufr)
 }
 
 /*********************************************************/
-Int32 mdc_mat_read_main_header7( fptr, h)
-  FILE *fptr; Mdc_Main_header7 *h;
+Int32 mdc_mat_read_main_header7(FILE *fptr, Mdc_Main_header7 *h)
 {
   Int16 b[256];
   char *bb;
@@ -547,10 +524,7 @@ Int32 mdc_mat_read_main_header7( fptr, h)
 /*******************************************************************/
 /*  May 90, PLuk - Now reads VAX or Sun matrix files.              */
 
-Int32 mdc_mat_read_mat_data( fptr, strtblk, nblks, dptr, dtype)
-  FILE *fptr;
-  Int32 strtblk, nblks, dtype;
-  Uint8 *dptr;
+Int32 mdc_mat_read_mat_data(FILE *fptr, Int32 strtblk, Int32 nblks, Uint8 *dptr, Int32 dtype)
 {
   Int32 i, error;
 
@@ -592,10 +566,7 @@ Int32 mdc_mat_read_mat_data( fptr, strtblk, nblks, dptr, dtype)
 }
 
 /*********************************************************/
-Int32 mdc_mat_read_mat_data7( fptr, strtblk, nblks, dptr, dtype)
-  FILE *fptr;
-  Int32 strtblk, nblks, dtype;
-  Uint8 *dptr;
+Int32 mdc_mat_read_mat_data7(FILE *fptr, Int32 strtblk, Int32 nblks, Uint8 *dptr, Int32 dtype)
 {
   Int32 i, error;
 
@@ -637,8 +608,7 @@ Int32 mdc_mat_read_mat_data7( fptr, strtblk, nblks, dptr, dtype)
 }
 
 /*********************************************************/
-Int32 mdc_mat_read_scan_subheader( fptr, blknum, h)
-  FILE *fptr; Int32 blknum; Mdc_Scan_subheader *h;
+Int32 mdc_mat_read_scan_subheader(FILE *fptr, Int32 blknum, Mdc_Scan_subheader *h)
 {
   Int16 b[256];
   Int32 i, err;
@@ -678,8 +648,7 @@ Int32 mdc_mat_read_scan_subheader( fptr, blknum, h)
   return (0);
 }
 /*********************************************************/
-Int32 mdc_mat_read_scan_subheader7( fptr, blknum, h)
-  FILE *fptr; Int32 blknum; Mdc_Scan_subheader7 *h;
+Int32 mdc_mat_read_scan_subheader7(FILE *fptr, Int32 blknum, Mdc_Scan_subheader7 *h)
 {
   Int16 b[256];
   Int32 err;
@@ -704,8 +673,7 @@ Int32 mdc_mat_read_scan_subheader7( fptr, blknum, h)
   return (0);
 }
 /*********************************************************/
-Int32 mdc_mat_read_image_subheader( fptr, blknum, h)
-  FILE *fptr; Int32 blknum; Mdc_Image_subheader *h;
+Int32 mdc_mat_read_image_subheader(FILE *fptr, Int32 blknum, Mdc_Image_subheader *h)
 {
   Int16 b[256];
   Int32 i, err;
@@ -757,8 +725,7 @@ Int32 mdc_mat_read_image_subheader( fptr, blknum, h)
   return (0);
 }
 /*********************************************************/
-Int32 mdc_mat_read_image_subheader7( fptr, blknum, h)
-  FILE *fptr; Int32 blknum; Mdc_Image_subheader7 *h;
+Int32 mdc_mat_read_image_subheader7(FILE *fptr, Int32 blknum, Mdc_Image_subheader7 *h)
 {
   Int16 b[256];
   Int32 i, err;
@@ -840,8 +807,7 @@ Int32 mdc_mat_read_image_subheader7( fptr, blknum, h)
 
 
 /*********************************************************/
-float mdc_get_vax_float( bufr, off)
-  Uint16 bufr[]; Int32 off;
+float mdc_get_vax_float(Uint16 bufr[], Int32 off)
 {
   Uint16 t1, t2;
   union {Uint32 t3; float t4;} test;
@@ -855,15 +821,12 @@ float mdc_get_vax_float( bufr, off)
 }
 
 /*********************************************************/
-Int32 mdc_get_vax_long( bufr, off)
-  Uint16 bufr[]; Int32 off;
+Int32 mdc_get_vax_long(Uint16 bufr[], Int32 off)
 {
   return ((bufr[off+1]<<16)+bufr[off]);
 }
 
-Mdc_Mat_dir mdc_mat_read_dir( fptr, selector)
-  FILE *fptr;
-  Uint8 *selector;
+Mdc_Mat_dir mdc_mat_read_dir(FILE *fptr, Uint8 *selector)
 { Int32 i, n, blk, nxtblk, ndblks, bufr[128];
   Mdc_Mat_dir dir;
 
@@ -904,10 +867,7 @@ Mdc_Mat_dir mdc_mat_read_dir( fptr, selector)
 
 /*********************************************************/
 
-Int32 mdc_mat_wblk( fptr, blkno, bufr, nblks)
-  FILE *fptr;
-  Int32 blkno, nblks;
-  Uint8 *bufr;
+Int32 mdc_mat_wblk(FILE *fptr, Int32 blkno, Uint8 *bufr, Int32 nblks)
 {
   Int32 err;
   /* seek to position in file */
@@ -921,9 +881,7 @@ Int32 mdc_mat_wblk( fptr, blkno, bufr, nblks)
   return (0);
 }
 
-FILE *mdc_mat_create( fname, mhead)
-  char *fname;
-  Mdc_Main_header *mhead;
+FILE *mdc_mat_create(char *fname, Mdc_Main_header *mhead)
 {
   FILE *fptr;
   Int32 i, *bufr;
@@ -944,8 +902,7 @@ FILE *mdc_mat_create( fname, mhead)
   return (fptr);
 }
 
-Int32 mdc_mat_enter( fptr, matnum, nblks)
-  FILE *fptr; Int32 matnum, nblks;
+Int32 mdc_mat_enter(FILE *fptr, Int32 matnum, Int32 nblks)
 {
 
   Int32 dirblk, dirbufr[128+4], i, nxtblk, busy, oldsize;
@@ -1028,12 +985,7 @@ Int32 mdc_mat_enter( fptr, matnum, nblks)
   return (nxtblk);
 }
 
-Int32 mdc_mat_write_image( fptr, matnum, header, data, data_size)
-  FILE *fptr;
-  Int32 matnum;
-  Mdc_Image_subheader *header;
-  Uint16 *data;
-  Int32 data_size;
+Int32 mdc_mat_write_image(FILE *fptr, Int32 matnum, Mdc_Image_subheader *header, Uint16 *data, Int32 data_size)
 {
   Int32 nxtblk, size, error ;
 
@@ -1046,12 +998,7 @@ Int32 mdc_mat_write_image( fptr, matnum, header, data, data_size)
   return(error) ;
 }
 
-Int32 mdc_mat_write_scan( fptr, matnum, header, data, data_size)
-  FILE *fptr;
-  Int32 matnum;
-  Mdc_Scan_subheader *header;
-  Uint16 *data;
-  Int32 data_size;
+Int32 mdc_mat_write_scan(FILE *fptr, Int32 matnum, Mdc_Scan_subheader *header, Uint16 *data, Int32 data_size)
 {
   Int32 nxtblk, size, error ;
 
@@ -1064,12 +1011,7 @@ Int32 mdc_mat_write_scan( fptr, matnum, header, data, data_size)
   return(error) ;
 }
 
-Int32 mdc_mat_write_attn( fptr, matnum, header, data, data_size)
-  FILE *fptr;
-  Int32 matnum;
-  Mdc_Attn_subheader *header;
-  float *data;
-  Int32 data_size;
+Int32 mdc_mat_write_attn(FILE *fptr, Int32 matnum, Mdc_Attn_subheader *header, float *data, Int32 data_size)
 {
   Int32 nxtblk, size, error ;
 
@@ -1082,12 +1024,7 @@ Int32 mdc_mat_write_attn( fptr, matnum, header, data, data_size)
   return(error) ;
 }
 
-Int32 mdc_mat_write_norm( fptr, matnum, header, data, data_size)
-  FILE *fptr;
-  Int32 matnum;
-  Mdc_Norm_subheader *header;
-  float *data;
-  Int32 data_size;
+Int32 mdc_mat_write_norm(FILE *fptr, Int32 matnum, Mdc_Norm_subheader *header, float *data, Int32 data_size)
 {
   Int32 nxtblk, size, error ;
 
@@ -1100,10 +1037,7 @@ Int32 mdc_mat_write_norm( fptr, matnum, header, data, data_size)
   return(error) ;
 }
 
-Int32 mdc_mat_write_idata( fptr, blk, data, size)
-  FILE *fptr;
-  Int32 blk, size;
-  Uint8 *data;
+Int32 mdc_mat_write_idata(FILE *fptr, Int32 blk, Uint8 *data, Int32 size)
 {
   Uint8 bufr[512];
   Int32 i, nbytes, nblks;
@@ -1122,10 +1056,7 @@ Int32 mdc_mat_write_idata( fptr, blk, data, size)
   return 0;
 }
 
-Int32 mdc_mat_write_fdata( fptr, blk, data, size)
-  FILE *fptr;
-  Int32 blk, size;
-  float *data;
+Int32 mdc_mat_write_fdata(FILE *fptr, Int32 blk, float *data, Int32 size)
 {
   float bufr[128];
   Int32 i, j, nvals, nblks;
@@ -1144,8 +1075,7 @@ Int32 mdc_mat_write_fdata( fptr, blk, data, size)
   return 0;
 }
 
-Int32 mdc_matrix_selector( matnum, ranges)
-  Int32 matnum, ranges[2][5];
+Int32 mdc_matrix_selector(Int32 matnum, Int32 ranges[2][5])
 {
   struct Mdc_Matval m;
 
@@ -1163,9 +1093,9 @@ Int32 mdc_matrix_selector( matnum, ranges)
   return (matnum);
 }
 
-Int32 mdc_decode_selector( s1, ranges)
-  char *s1; Int32 ranges[2][5];
-{ char xword[16];
+Int32 mdc_decode_selector(char *s1, Int32 ranges[2][5])
+{ 
+  char xword[16];
   Int32 i;
 
   mdc_fix_selector( s1, s1);
@@ -1183,8 +1113,7 @@ Int32 mdc_decode_selector( s1, ranges)
   return 0;
 }
 
-Int32 mdc_str_find( s1, s2)
-  char *s1, *s2;
+Int32 mdc_str_find(char *s1, char *s2)
 {
   Int32 i, j, k;
 
@@ -1194,8 +1123,7 @@ Int32 mdc_str_find( s1, s2)
   } return (-1);
 }
 
-Int32 mdc_str_replace( s1, s2, s3, s4)
-  char *s1, *s2, *s3, *s4;
+Int32 mdc_str_replace(char *s1, char *s2, char *s3, char *s4)
 {
   Int32 nf=0, n;
 
@@ -1213,8 +1141,7 @@ Int32 mdc_str_replace( s1, s2, s3, s4)
   }
 }
 
-Int32 mdc_string_replace( s1, s2, s3, s4)
-  char *s1, *s2, *s3, *s4;
+Int32 mdc_string_replace(char *s1, char *s2, char *s3, char *s4)
 {
   char temp[256];
 
@@ -1224,8 +1151,7 @@ Int32 mdc_string_replace( s1, s2, s3, s4)
   return 0;
 }
 
-Int32 mdc_fix_selector( s1, s2)
-  char *s1, *s2;
+Int32 mdc_fix_selector(char *s1, char *s2)
 {
   char temp[256];
   mdc_string_replace(temp, s2, "," , " ");
@@ -1239,8 +1165,7 @@ Int32 mdc_fix_selector( s1, s2)
   return 0;
 }
 
-char* mdc_nex_word(s, w)
-  char *s, *w;
+char* mdc_nex_word(char *s, char *w)
 {
   while (*s && *s!=' ') *w++=*s++;
   *w='\0';
@@ -1283,8 +1208,7 @@ Int32 mdc_hostftovaxf(float f_orig, Uint16 number[])
 }
 
 /*********************************************************/
-Int32 mdc_mat_write_main_header( fptr, header)
-  FILE *fptr; Mdc_Main_header *header;
+Int32 mdc_mat_write_main_header(FILE *fptr, Mdc_Main_header *header)
 {
   Uint8 *bbufr;
   Int16 bufr[256];
@@ -1383,8 +1307,7 @@ Int32 mdc_mat_write_main_header( fptr, header)
 
 /*********************************************************/
 
-Int32 mdc_mat_write_image_subheader( fptr, blknum, header)
-  FILE *fptr; Int32 blknum; Mdc_Image_subheader *header;
+Int32 mdc_mat_write_image_subheader(FILE *fptr, Int32 blknum, Mdc_Image_subheader *header)
 {
   Uint8 *bbufr;
   Int16 bufr[256];
@@ -1447,9 +1370,7 @@ Int32 mdc_mat_write_image_subheader( fptr, blknum, header)
 }
 
 /*********************************************************/
-Int32 mdc_hostltovaxl( in, out)
-  Int32 in;
-  Uint16 out[2];
+Int32 mdc_hostltovaxl(Int32 in, Uint16 out[2])
 {
 
   out[0]=(in&0x0000FFFF);
@@ -1459,10 +1380,7 @@ Int32 mdc_hostltovaxl( in, out)
 }
 
 /*********************************************************/
-Int32 mdc_mat_write_scan_subheader( fptr, blknum, header)
-  FILE *fptr;
-  Int32 blknum;
-  Mdc_Scan_subheader *header;
+Int32 mdc_mat_write_scan_subheader(FILE *fptr, Int32 blknum, Mdc_Scan_subheader *header)
 {
   Int16 bufr[256];
   Int32 i, err;
@@ -1524,10 +1442,7 @@ Int32 mdc_mat_write_scan_subheader( fptr, blknum, header)
   return (err);
 }
 
-Int32 mdc_mat_write_attn_subheader( fptr, blknum, header)
-  FILE *fptr;
-  Int32 blknum;
-  Mdc_Attn_subheader *header;
+Int32 mdc_mat_write_attn_subheader(FILE *fptr, Int32 blknum, Mdc_Attn_subheader *header)
 {
   Int16 bufr[256];
   Int32 i,err;
@@ -1567,10 +1482,7 @@ Int32 mdc_mat_write_attn_subheader( fptr, blknum, header)
   return (err);
 }
 
-Int32 mdc_mat_write_norm_subheader( fptr, blknum, header)
-  FILE *fptr;
-  Int32 blknum;
-  Mdc_Norm_subheader *header;
+Int32 mdc_mat_write_norm_subheader(FILE *fptr, Int32 blknum, Mdc_Norm_subheader *header)
 {
   Int16 bufr[256];
   Int32 i,err;
@@ -1610,10 +1522,7 @@ Int32 mdc_mat_write_norm_subheader( fptr, blknum, header)
   return (err);
 }
 
-Int32 mdc_mat_read_attn_subheader( fptr, blknum, header)
-  FILE *fptr;
-  Int32 blknum;
-  Mdc_Attn_subheader *header;
+Int32 mdc_mat_read_attn_subheader(FILE *fptr, Int32 blknum, Mdc_Attn_subheader *header)
 {
   Int16 bufr[256];
   Int32 err;
@@ -1638,10 +1547,7 @@ Int32 mdc_mat_read_attn_subheader( fptr, blknum, header)
   return (0);
 }
 
-Int32 mdc_mat_read_attn_subheader7( fptr, blknum, h)
-  FILE *fptr;
-  Int32 blknum;
-  Mdc_Attn_subheader7 *h;
+Int32 mdc_mat_read_attn_subheader7(FILE *fptr, Int32 blknum, Mdc_Attn_subheader7 *h)
 {
   Int16 b[256];
   Int32 err, i;
@@ -1690,8 +1596,7 @@ Int32 mdc_mat_read_attn_subheader7( fptr, blknum, h)
   return (0);
 }
 
-Int32 mdc_mat_read_norm_subheader( fptr, blknum, header)
-  FILE *fptr; Int32 blknum; Mdc_Norm_subheader *header;
+Int32 mdc_mat_read_norm_subheader(FILE *fptr, Int32 blknum, Mdc_Norm_subheader *header)
 {
   Int16 bufr[256];
   Int32 err;
@@ -1719,12 +1624,7 @@ Int32 mdc_mat_read_norm_subheader( fptr, blknum, header)
 /* Following function was copied from CTI-source file 'matrix_extra.c' */
 /* and slightly modified ...                                           */
 
-Int32 mdc_write_matrix_data(fptr, strtblk, nblks, dptr, dtype)
-  FILE *fptr;
-  Int32 strtblk,
-  nblks,
-  dtype;
-Uint8 *dptr;
+Int32 mdc_write_matrix_data(FILE *fptr, Int32 strtblk, Int32 nblks, Uint8 *dptr, Int32 dtype)
 {
   Int32 err;
 
