@@ -20,7 +20,7 @@
  */
 
 /*
-   Copyright (C) 1997-2025 by Erik Nolf
+   Copyright (C) 1997-2026 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -267,6 +267,7 @@ char *MdcReadPNG(FILEINFO *fi)
       break;
 
     case PNG_COLOR_TYPE_RGB:
+      MdcFree(id->buf); /* no longer needed */
       /* get contiguous RGB memory block */
       imgRGB = malloc(height * rowbytes);
       if (imgRGB == NULL) {
@@ -294,6 +295,8 @@ char *MdcReadPNG(FILEINFO *fi)
   /* finishing up */
   png_destroy_read_struct(&png_ptr, &info_ptr, (png_infopp)NULL);
 
+  MdcCloseFile(fi->ifp);
+
   if (MDC_PROGRESS) MdcProgress(MDC_PROGRESS_SET,1.0,NULL);
 
   return(NULL);
