@@ -27,7 +27,7 @@
  */
 
 /*
-   Copyright (C) 1997-2025 by Erik Nolf
+   Copyright (C) 1997-2026 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -580,19 +580,18 @@ gboolean XMdcChangeLUT(GtkWidget *spinner, gpointer data)
   if (nr == sColormapSelection.Nr) return(TRUE);
 
   /* make appropriate path name */
-  sprintf(lutname,"ct%03d.lut",nr);
   if (XMEDCONLUT != NULL) {
+    /* preference for external files */
     strncpy(xmdcstr,XMEDCONLUT,MDC_1KB_OFFSET); xmdcstr[strlen(xmdcstr)]='\0';
-     if (xmdcstr[strlen(xmdcstr)-1] != MDC_PATH_DELIM_CHR)
-       strcat(xmdcstr,MDC_PATH_DELIM_STR);
+    if (xmdcstr[strlen(xmdcstr)-1] != MDC_PATH_DELIM_CHR)
+      strcat(xmdcstr,MDC_PATH_DELIM_STR);
+
+    sprintf(lutname,"ct%03d.lut",nr); strcat(xmdcstr,lutname);
   }else{
-    /* installation dir */
-    strncpy(xmdcstr,XMDCLUT,MDC_1KB_OFFSET);    xmdcstr[strlen(xmdcstr)]='\0';
+    /* use internal palette */
+    sprintf(xmdcstr,"%d",nr);
   }
 
-  sprintf(lutname,"ct%03d.lut",nr); strcat(xmdcstr,lutname);
-
-
   if (XMdcLoadLUT(xmdcstr) == MDC_YES) {
     /* set to new LUT number */
     sColormapSelection.Nr = nr;
