@@ -12,7 +12,7 @@
  */
 
 /*
-   Copyright (C) 1997-2025 by Erik Nolf
+   Copyright (C) 1997-2026 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -70,6 +70,8 @@ char   labelindex[50];
 char   labeltimes[50];
 Uint32 write_counter=0;
 char   xmdcstr[MDC_2KB_OFFSET];
-char  *XMEDCONLUT=NULL; /* environ var: dir to color lookup tables    */
-char  *XMEDCONRPI=NULL; /* environ var: dir to raw predef input files */
+char  *XMEDCONLUT=NULL; /* env. var.: dir to color lookup tables    */
+char  *XMEDCONRPI=NULL; /* env. var.: dir to raw predef input files */
+char  *XMEDCONUSR=NULL; /* env. var.: dir to user home profile      */
+char  *XMEDCONCSS=NULL; /* env. var.: file to css theme layout      */
 
