@@ -12,7 +12,7 @@
  */
 
 /*
-   Copyright (C) 1997-2025 by Erik Nolf
+   Copyright (C) 1997-2026 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -336,6 +336,8 @@ extern Uint32 write_counter;
 extern char xmdcstr[MDC_2KB_OFFSET];
 extern char *XMEDCONLUT;
 extern char *XMEDCONRPI;
+extern char *XMEDCONUSR;
+extern char *XMEDCONCSS;
 
 #endif
 
