@@ -14,7 +14,7 @@
  */
 
 /*
-   Copyright (C) 1997-2025 by Erik Nolf
+   Copyright (C) 1997-2026 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -155,7 +155,9 @@ int main(int argc, char *argv[])
 
     XMdcCreateLogConsole();
 
-    XMdcConfigureByCss();
+    XMdcGetEnvVars();
+
+    XMdcConfigureCssTheme();
 
     my.mainwindow = gtk_window_new(GTK_WINDOW_TOPLEVEL);
     g_signal_connect(my.mainwindow, "destroy",
