@@ -10,7 +10,6 @@
  * Functions    : XMdcMedconQuit()            - Quit XMedCon main program  *
  *                XMdcMainWidgetsInsensitive()- Make them insensitive      *
  *                XMdcMainWidgetsResensitive()- Make them   sensitive      *
- *                XMdcConfigureByCss()        - Parse CSS style file       *
  *                XMdcAskYesNo()              - Ask a Yes/No question      *
  *                XMdcRunDialog()             - Run modal dialog           *
  *                XMdcShowWidget()            - Our show the widget routine*
@@ -26,6 +25,7 @@
  *                XMdcScaleW()                - Scale image width          *
  *                XMdcScaleH()                - Scale image height         *
  *                XMdcGetScreenWorkingArea()  - Get screen working area    *
+ *                XMdcGetEnvVars()            - Get environment variables  *
  *                                                                         *
  * Note         : Algoritme for gamma/brightness/contrast correction in    *
  *                function XMdcSetGbcCorrection() copied from library      *
@@ -36,7 +36,7 @@
  */
 
 /*
-   Copyright (C) 1997-2025 by Erik Nolf
+   Copyright (C) 1997-2026 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -99,86 +99,6 @@ void XMdcMainWidgetsResensitive(void)
 
 }
 
-void XMdcConfigureByCss(void)
-{
-  GtkCssProvider *provider;
-  GdkDisplay *display;
-  GdkScreen *screen;
-  GFile *css_fp = NULL;
-  GError *error = NULL;
-  char *h;
-
-  provider = gtk_css_provider_new();
-  display  = gdk_display_get_default();
-  screen   = gdk_display_get_default_screen(display);
-
-  gtk_style_context_add_provider_for_screen(screen,
-                                            GTK_STYLE_PROVIDER(provider),
-                                            GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
-
-  MdcDebugPrint("XMDCCSS = %s",XMDCCSS);
-  MdcDebugPrint("XMDCWEB = %s",XMDCWEB);
-
-  XMEDCONLUT = getenv("XMEDCONLUT");
-  XMEDCONRPI = getenv("XMEDCONRPI");
-
-#ifdef _WIN32
-  /* try windows Program Files path */
-  sprintf(xmdcstr,"c:\\program files\\xmedcon\\etc\\xmedcon.css");
-  if (MdcFileExists(xmdcstr)) {
-    MdcDebugPrint("CSS file found in \"Program Files\"");
-
-    css_fp = g_file_new_for_path(xmdcstr);
-    gtk_css_provider_load_from_file(provider, css_fp, &error);
-    g_object_unref(provider);
-
-    return;
-  }
-#else
-  /* try unixes HOME environment variable */
-  h = getenv("HOME");
-  if (h != NULL) {
-    sprintf(xmdcstr,"%s/.xmedcon.css",h);
-    if (MdcFileExists(xmdcstr)) {
-      MdcDebugPrint("CSS file found in HOME = %s",xmdcstr);
-
-      css_fp = g_file_new_for_path(xmdcstr);
-      gtk_css_provider_load_from_file(provider, css_fp, &error);
-      g_object_unref(provider);
-
-      return;
-    }
-  }
-#endif
-
-  /* try XMEDCON_CSS environment variable */
-  h = getenv("XMEDCONCSS");
-  if (h != NULL) {
-    if (MdcFileExists(h)) {
-      sprintf(xmdcstr,"%s",h);
-      MdcDebugPrint("CSS file found in XMEDCONCSS = %s",xmdcstr);
-
-      css_fp = g_file_new_for_path(xmdcstr);
-      gtk_css_provider_load_from_file(provider, css_fp, &error);
-      g_object_unref(provider);
-
-      return;
-    }
-  }
-
-  /* try hardcoded install path */
-  if (MdcFileExists(XMDCCSS)) {
-    MdcDebugPrint("CSS file found in XMDCCSS = %s",XMDCCSS);
-
-    css_fp = g_file_new_for_path(XMDCCSS);
-    gtk_css_provider_load_from_file(provider, css_fp, &error);
-    g_object_unref(provider);
-
-    return;
-  }
-
-}
-
 void XMdcAskYesNo(GCallback YesFunc, GCallback NoFunc, char *question)
 {
   GtkWidget *dialog;
@@ -473,3 +393,24 @@ void XMdcGetScreenWorkingArea(void)
   MdcDebugPrint("screen_width      = %d",my.screen_width);
 
 }
+
+void XMdcGetEnvVars(void)
+{
+
+  /* dir to color lookup tables */ 
+  XMEDCONLUT = getenv("XMEDCONLUT");
+
+  /* dir to raw predef input files */
+  XMEDCONRPI = getenv("XMEDCONRPI");
+
+  /* dir to user home directory */
+#ifdef _WIN32
+  XMEDCONUSR = getenv("USERPROFILE");
+#else
+  XMEDCONUSR = getenv("HOME");
+#endif
+
+  /* file to css theme layout */
+  XMEDCONCSS = getenv("XMEDCONCSS");
+
+}
