@@ -12,7 +12,7 @@
  */
 
 /*
-   Copyright (C) 1997-2025 by Erik Nolf
+   Copyright (C) 1997-2026 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -38,7 +38,6 @@
 void XMdcMedconQuit(GtkWidget *widget, gpointer data);
 void XMdcMainWidgetsInsensitive(void);
 void XMdcMainWidgetsResensitive(void);
-void XMdcConfigureByCss(void);
 void XMdcAskYesNo(GCallback YesFunc, GCallback NoFunc, char *question);
 void XMdcRunDialog(GtkWidget *dialog);
 void XMdcShowWidget(GtkWidget *widget);
@@ -54,6 +53,7 @@ void XMdcSetImageScales(void);
 Uint32 XMdcScaleW(Uint32 width);
 Uint32 XMdcScaleH(Uint32 height);
 void XMdcGetScreenWorkingArea(void);
+void XMdcGetEnvVars(void);
 
 #endif
 
