@@ -20,7 +20,7 @@
  */
 
 /*
-   Copyright (C) 1997-2025 by Erik Nolf
+   Copyright (C) 1997-2026 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -428,8 +428,15 @@ void XMdcBuildViewerWindow(void)
   gtk_box_pack_start(GTK_BOX(entrybox),label,FALSE,TRUE,5);
   gtk_widget_show(label);
 
-  adj=(GtkAdjustment *)gtk_adjustment_new(1., 1., (float)XMDC_MAX_LOADABLE_LUTS,
-                                          1., 5., 0.);
+  if (XMEDCONLUT != NULL) {
+    /* preference for external files */
+    adj=(GtkAdjustment *)gtk_adjustment_new(1., 1., (float)XMDC_MAX_LOADABLE_LUTS,
+                                            1., 5., 0.);
+  }else{
+    /* use internal palette */
+    adj=(GtkAdjustment *)gtk_adjustment_new(1., 1., (float)(mdc_max_palette-1),
+                                            1., 5., 0.);
+  }
 
   spinner = gtk_spin_button_new(adj, 0.0, 0);
   gtk_spin_button_set_wrap(GTK_SPIN_BUTTON(spinner), TRUE);
